# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.beneficiary_bank_account_groups_list
import earthport-rest-api-client.models.beneficiary_identity_groups_list
import earthport-rest-api-client.models.purpose_of_payment_field_groups_list

class GetPayoutRequiredDataResponse(object):

    """Implementation of the 'GetPayoutRequiredDataResponse' model.

    All the data required to settle a payment with a given currency into a
    given country.

    Attributes:
        beneficiary_bank_account_field_groups_list
            (BeneficiaryBankAccountGroupsList): This type defines a list of
            bank account data groups. Each group is normally represented as a
            row on the UI.
        beneficiary_identity_field_groups_list
            (BeneficiaryIdentityGroupsList): This type defines a list of
            identity data groups. Each group is normally represented as a
            section of fields on the UI.
        purpose_of_payment_field_groups_list
            (PurposeOfPaymentFieldGroupsList): This group contains all
            configuration information for Purpose of Payment options. The
            'mandatory' attribute indicates whether provision of Purpose of
            Payment data is required for the Payout to be accepted.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "beneficiary_bank_account_field_groups_list":'beneficiaryBankAccountFieldGroupsList',
        "beneficiary_identity_field_groups_list":'beneficiaryIdentityFieldGroupsList',
        "purpose_of_payment_field_groups_list":'purposeOfPaymentFieldGroupsList'
    }

    def __init__(self,
                 beneficiary_bank_account_field_groups_list=None,
                 beneficiary_identity_field_groups_list=None,
                 purpose_of_payment_field_groups_list=None):
        """Constructor for the GetPayoutRequiredDataResponse class"""

        # Initialize members of the class
        self.beneficiary_bank_account_field_groups_list = beneficiary_bank_account_field_groups_list
        self.beneficiary_identity_field_groups_list = beneficiary_identity_field_groups_list
        self.purpose_of_payment_field_groups_list = purpose_of_payment_field_groups_list


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        beneficiary_bank_account_field_groups_list = earthport-rest-api-client.models.beneficiary_bank_account_groups_list.BeneficiaryBankAccountGroupsList.from_dictionary(dictionary.get('beneficiaryBankAccountFieldGroupsList')) if dictionary.get('beneficiaryBankAccountFieldGroupsList') else None
        beneficiary_identity_field_groups_list = earthport-rest-api-client.models.beneficiary_identity_groups_list.BeneficiaryIdentityGroupsList.from_dictionary(dictionary.get('beneficiaryIdentityFieldGroupsList')) if dictionary.get('beneficiaryIdentityFieldGroupsList') else None
        purpose_of_payment_field_groups_list = earthport-rest-api-client.models.purpose_of_payment_field_groups_list.PurposeOfPaymentFieldGroupsList.from_dictionary(dictionary.get('purposeOfPaymentFieldGroupsList')) if dictionary.get('purposeOfPaymentFieldGroupsList') else None

        # Return an object of this model
        return cls(beneficiary_bank_account_field_groups_list,
                   beneficiary_identity_field_groups_list,
                   purpose_of_payment_field_groups_list)





# -*- coding: utf-8 -*-


class AccessTokenResponse(object):

    """Implementation of the 'AccessTokenResponse' model.

    The OAuth 2.0 access token to be used in each subsequent API call.

    Attributes:
        token_type (string): Type of token.
        issued_at (string): Time the token was issued. This is milliseconds
            since epoch.
        access_token (string): The actual token which needs to be used to
            authorize each subsequent API request.
        expires_in (string): When this token expires in seconds.
        status (string): The status of the token.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "access_token":'access_token',
        "token_type":'token_type',
        "issued_at":'issued_at',
        "expires_in":'expires_in',
        "status":'status'
    }

    def __init__(self,
                 access_token=None,
                 token_type=None,
                 issued_at=None,
                 expires_in=None,
                 status=None):
        """Constructor for the AccessTokenResponse class"""

        # Initialize members of the class
        self.token_type = token_type
        self.issued_at = issued_at
        self.access_token = access_token
        self.expires_in = expires_in
        self.status = status


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        access_token = dictionary.get('access_token')
        token_type = dictionary.get('token_type')
        issued_at = dictionary.get('issued_at')
        expires_in = dictionary.get('expires_in')
        status = dictionary.get('status')

        # Return an object of this model
        return cls(access_token,
                   token_type,
                   issued_at,
                   expires_in,
                   status)





# -*- coding: utf-8 -*-

class GrantTypeEnum(object):

    """Implementation of the 'grant_type' enum.

    TODO: type enum description here.

    Attributes:
        CLIENT_CREDENTIALS: TODO: type description here.

    """

    CLIENT_CREDENTIALS = 'client_credentials'




# -*- coding: utf-8 -*-


class UnstructuredIdentity(object):

    """Implementation of the 'UnstructuredIdentity' model.

    Represents a set of name value pairs that can be supplied as the Identity
    information. The keys will be validated on the server side against a list
    of valid types that are accepted. Both the key and the value are
    required.

    Attributes:
        key (string): TODO: type description here.
        value (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "key":'Key',
        "value":'Value'
    }

    def __init__(self,
                 key=None,
                 value=None):
        """Constructor for the UnstructuredIdentity class"""

        # Initialize members of the class
        self.key = key
        self.value = value


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        key = dictionary.get('Key')
        value = dictionary.get('Value')

        # Return an object of this model
        return cls(key,
                   value)





# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.bulk_fx_detail

class CreateBulkFXQuoteResponse(object):

    """Implementation of the 'Create Bulk FX QuoteResponse' model.

    Bulk FX Quote Response.

    Attributes:
        fx_ticket_id (int): Generic entity identity.
        expiry_timestamp (string): TODO: type description here.
        bulk_fx_detail (list of BulkFXDetail): Represents the list of fxRates
            and their details.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "fx_ticket_id":'fxTicketID',
        "expiry_timestamp":'expiryTimestamp',
        "bulk_fx_detail":'bulkFXDetail'
    }

    def __init__(self,
                 fx_ticket_id=None,
                 expiry_timestamp=None,
                 bulk_fx_detail=None):
        """Constructor for the CreateBulkFXQuoteResponse class"""

        # Initialize members of the class
        self.fx_ticket_id = fx_ticket_id
        self.expiry_timestamp = expiry_timestamp
        self.bulk_fx_detail = bulk_fx_detail


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        fx_ticket_id = dictionary.get('fxTicketID')
        expiry_timestamp = dictionary.get('expiryTimestamp')
        bulk_fx_detail = None
        if dictionary.get('bulkFXDetail') != None:
            bulk_fx_detail = list()
            for structure in dictionary.get('bulkFXDetail'):
                bulk_fx_detail.append(earthport-rest-api-client.models.bulk_fx_detail.BulkFXDetail.from_dictionary(structure))

        # Return an object of this model
        return cls(fx_ticket_id,
                   expiry_timestamp,
                   bulk_fx_detail)





# -*- coding: utf-8 -*-

from .base_controller import BaseController
from ..api_helper import APIHelper
from ..configuration import Configuration
from ..http.auth.custom_header_auth import CustomHeaderAuth
from ..models.user_id import UserID
from ..models.get_user_response import GetUserResponse
from ..exceptions.api_exception import APIException

class UsersController(BaseController):

    """A Controller to access Endpoints in the earthport-rest-api-client API."""


    def create_or_validate_user(self,
                                action=None,
                                beneficiary_country_code=None,
                                create_validate_user_request=None):
        """Does a POST request to /users.

        Registers a new user for the client. A User is responsible for
        registering the beneficiary bank account to which a payment is sent
        to. This normally means the User is the Payer. You can also use this
        API to validate the payer identity details of the User by supplying
        the optional request parameter action=validate.

        Args:
            action (ActionEnum, optional): action=validate, validates the user
                without storing it. This API currently supports validating the
                user identity only.
            beneficiary_country_code (string, optional): Valid supported ISO
                3166 2-character country code. This is required parameter when
                action=validate
            create_validate_user_request (CreateValidateUserRequest,
                optional): The user details to either be created or
                validated.

        Returns:
            UserID: Response from the API. User succesfully created.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.get_base_uri()
        _query_builder += '/users'
        _query_parameters = {
            'action': action,
            'beneficiaryCountryCode': beneficiary_country_code
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(create_validate_user_request))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 400:
            raise APIException('The requested operation could not be performed. Input Request is invalid or incorrect.', _context)
        elif _context.response.status_code == 401:
            raise APIException('Unauthorized - Invalid API Key and Token.', _context)
        elif _context.response.status_code == 500:
            raise APIException('An internal error has occurred in the Earthport payment platform.', _context)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, UserID.from_dictionary)

    def get_user(self,
                 user_id,
                 id_type=None):
        """Does a GET request to /users/{userID}.

        Get a User/Payer. This API only returns the identity details of a
        User/Payer.

        Args:
            user_id (string): The payer's unique id. It can be either VAN or
                merchant id.
            id_type (IdTypeEnum, optional): idType for the path parameters.
                This allows you to specify either your own UIDs or Earthport
                generated UIDs. The Earthport generated UIDs will be used by
                default.

        Returns:
            GetUserResponse: Response from the API. User succesfully
                returned.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.get_base_uri()
        _query_builder += '/users/{userID}'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'userID': user_id
        })
        _query_parameters = {
            'idType': id_type
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 400:
            raise APIException('The requested operation could not be performed. Input Request is invalid or incorrect.', _context)
        elif _context.response.status_code == 401:
            raise APIException('Unauthorized - Invalid API Key and Token.', _context)
        elif _context.response.status_code == 500:
            raise APIException('An internal error has occurred in the Earthport payment platform.', _context)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetUserResponse.from_dictionary)

    def update_user(self,
                    user_id,
                    update_user_request=None,
                    id_type=None):
        """Does a PUT request to /users/{userID}.

        Updates a User/Payer. This API only supports updating the identity
        details of a User/Payer.

        Args:
            user_id (string): The payer's unique id. It can be either VAN or
                merchant id.
            update_user_request (UpdateUserRequest, optional): The user.
            id_type (IdTypeEnum, optional): idType for the path parameters.
                This allows you to specify either your own UIDs or Earthport
                generated UIDs. The Earthport generated UIDs will be used by
                default.

        Returns:
            void: Response from the API. User succesfully updated.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.get_base_uri()
        _query_builder += '/users/{userID}'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'userID': user_id
        })
        _query_parameters = {
            'idType': id_type
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_user_request))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 400:
            raise APIException('The requested operation could not be performed. Input Request is invalid or incorrect.', _context)
        elif _context.response.status_code == 401:
            raise APIException('Unauthorized - Invalid API Key and Token.', _context)
        elif _context.response.status_code == 500:
            raise APIException('An internal error has occurred in the Earthport payment platform.', _context)
        self.validate_response(_context)

    def delete_disable_user(self,
                            user_id,
                            id_type=None):
        """Does a DELETE request to /users/{userID}.

        Disables a User - you cannot register new bank accounts against a
        disabled User or create payments for a disabled User.

        Args:
            user_id (string): The payer's unique id. It can be either VAN or
                merchant id.
            id_type (IdTypeEnum, optional): idType for the path parameters.
                This allows you to specify either your own UIDs or Earthport
                generated UIDs. The Earthport generated UIDs will be used by
                default.

        Returns:
            void: Response from the API. User succesfully disabled.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.get_base_uri()
        _query_builder += '/users/{userID}'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'userID': user_id
        })
        _query_parameters = {
            'idType': id_type
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.delete(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 400:
            raise APIException('The requested operation could not be performed. Input Request is invalid or incorrect.', _context)
        elif _context.response.status_code == 401:
            raise APIException('Unauthorized - Invalid API Key and Token.', _context)
        elif _context.response.status_code == 500:
            raise APIException('An internal error has occurred in the Earthport payment platform.', _context)
        self.validate_response(_context)

    def add_deposit_reference(self,
                              user_id,
                              add_deposit_reference_request,
                              id_type=None):
        """Does a POST request to /users/{userID}/deposit-references.

        Creates a deposit reference for a User. This deposit reference is
        unique and each merchant has their own prefix.

        Args:
            user_id (string): The payer's unique id. It can be either VAN or
                merchant id.
            add_deposit_reference_request (AddDepositReferenceRequest):
                Deposit Reference.
            id_type (IdTypeEnum, optional): idType for the path parameters.
                This allows you to specify either your own UIDs or Earthport
                generated UIDs. The Earthport generated UIDs will be used by
                default.

        Returns:
            void: Response from the API. Deposit Reference Created.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.get_base_uri()
        _query_builder += '/users/{userID}/deposit-references'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'userID': user_id
        })
        _query_parameters = {
            'idType': id_type
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(add_deposit_reference_request))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 400:
            raise APIException('The requested operation could not be performed. Input Request is invalid or incorrect.', _context)
        elif _context.response.status_code == 401:
            raise APIException('Unauthorized - Invalid API Key and Token.', _context)
        elif _context.response.status_code == 500:
            raise APIException('An internal error has occurred in the Earthport payment platform.', _context)
        self.validate_response(_context)



# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.transaction_id
import earthport-rest-api-client.models.financial_transaction_status
import earthport-rest-api-client.models.monetary_value
import earthport-rest-api-client.models.statement_detail
import earthport-rest-api-client.models.fx_executed_rate
import earthport-rest-api-client.models.user_id

class UserDepositTransaction(object):

    """Implementation of the 'UserDepositTransaction' model.

    A financial transaction representing money paid into a merchant's account
    by a user.

    Attributes:
        transaction_id (TransactionID): Transaction ID type which contains
            both the unique Earthport transaction ID and the merchant supplied
            transaction ID.
        timestamp (string): TODO: type description here.
        transaction_type (string): TODO: type description here.
        transaction_status (FinancialTransactionStatus): Additional important
            status information for specific transaction types.
        amount (MonetaryValue): Represents a monetary value containing a
            decimal amount value along with a currency code. The currency code
            is a three letter ISO 4217 code. E.g. GBP for British sterling
            pounds.
        movement_type (MoneyMovementTypeEnum): Specifies whether a money
            movement is a debit or credit
        statement_details (list of StatementDetail): TODO: type description
            here.
        amount_deposited_by_user (MonetaryValue): Represents a monetary value
            containing a decimal amount value along with a currency code. The
            currency code is a three letter ISO 4217 code. E.g. GBP for
            British sterling pounds.
        amount_deposited_to_merchant (MonetaryValue): Represents a monetary
            value containing a decimal amount value along with a currency
            code. The currency code is a three letter ISO 4217 code. E.g. GBP
            for British sterling pounds.
        deposit_country (string): Valid supported ISO 3166 2-character country
            code.
        deposit_date (string): Valid ISO 8601 date format YYYY-MM-DD.
        deposit_reference (string): A Merchant User Deposit Reference.
        fx_executed_detail (FXExecutedRate): Holds details of an executed FX
            conversion that has occured as part of a financial transaction.
            The FX that occured was from the sellCurrency to the buyCurrency
            at a particular rate. The rate may have been requested via an FX
            Quote (fxTicketID). An FX conversion fee may have been applied to
            certain transaction types.
        unapplied_reason (string): TODO: type description here.
        user_id (UserID): This group consists of all possible user identifier
            types. The 'epUserID' field is a unique identifier for a merchant
            and is the equivalent of a Virtual Account Number (VAN). The
            'merchantUserID' is a merchant specified identifier for an
            individual or company that an account was set up for. The
            'epUserID', 'merchantUserID' or both 'epUserID' and
            'merchantUserID' can be supplied. A mapping will be performed to
            retrieve the merchant user ID from the supplied EP user ID and
            vice versa. If both the 'epUserID' and 'merchantUserID' are
            supplied, a check will be performed to ensure that the two are
            mapped. If the two provided fields are not mapped, then a
            validation error code will be returned. At least one of the fields
            must be populated.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "transaction_id":'transactionID',
        "timestamp":'timestamp',
        "transaction_type":'transactionType',
        "amount":'amount',
        "movement_type":'movementType',
        "amount_deposited_by_user":'amountDepositedByUser',
        "amount_deposited_to_merchant":'amountDepositedToMerchant',
        "deposit_country":'depositCountry',
        "deposit_date":'depositDate',
        "user_id":'userID',
        "transaction_status":'transactionStatus',
        "statement_details":'statementDetails',
        "deposit_reference":'depositReference',
        "fx_executed_detail":'fxExecutedDetail',
        "unapplied_reason":'unappliedReason'
    }

    def __init__(self,
                 transaction_id=None,
                 timestamp=None,
                 transaction_type=None,
                 amount=None,
                 movement_type=None,
                 amount_deposited_by_user=None,
                 amount_deposited_to_merchant=None,
                 deposit_country=None,
                 deposit_date=None,
                 user_id=None,
                 transaction_status=None,
                 statement_details=None,
                 deposit_reference=None,
                 fx_executed_detail=None,
                 unapplied_reason=None):
        """Constructor for the UserDepositTransaction class"""

        # Initialize members of the class
        self.transaction_id = transaction_id
        self.timestamp = timestamp
        self.transaction_type = transaction_type
        self.transaction_status = transaction_status
        self.amount = amount
        self.movement_type = movement_type
        self.statement_details = statement_details
        self.amount_deposited_by_user = amount_deposited_by_user
        self.amount_deposited_to_merchant = amount_deposited_to_merchant
        self.deposit_country = deposit_country
        self.deposit_date = deposit_date
        self.deposit_reference = deposit_reference
        self.fx_executed_detail = fx_executed_detail
        self.unapplied_reason = unapplied_reason
        self.user_id = user_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        transaction_id = earthport-rest-api-client.models.transaction_id.TransactionID.from_dictionary(dictionary.get('transactionID')) if dictionary.get('transactionID') else None
        timestamp = dictionary.get('timestamp')
        transaction_type = dictionary.get('transactionType')
        amount = earthport-rest-api-client.models.monetary_value.MonetaryValue.from_dictionary(dictionary.get('amount')) if dictionary.get('amount') else None
        movement_type = dictionary.get('movementType')
        amount_deposited_by_user = earthport-rest-api-client.models.monetary_value.MonetaryValue.from_dictionary(dictionary.get('amountDepositedByUser')) if dictionary.get('amountDepositedByUser') else None
        amount_deposited_to_merchant = earthport-rest-api-client.models.monetary_value.MonetaryValue.from_dictionary(dictionary.get('amountDepositedToMerchant')) if dictionary.get('amountDepositedToMerchant') else None
        deposit_country = dictionary.get('depositCountry')
        deposit_date = dictionary.get('depositDate')
        user_id = earthport-rest-api-client.models.user_id.UserID.from_dictionary(dictionary.get('userID')) if dictionary.get('userID') else None
        transaction_status = earthport-rest-api-client.models.financial_transaction_status.FinancialTransactionStatus.from_dictionary(dictionary.get('transactionStatus')) if dictionary.get('transactionStatus') else None
        statement_details = None
        if dictionary.get('statementDetails') != None:
            statement_details = list()
            for structure in dictionary.get('statementDetails'):
                statement_details.append(earthport-rest-api-client.models.statement_detail.StatementDetail.from_dictionary(structure))
        deposit_reference = dictionary.get('depositReference')
        fx_executed_detail = earthport-rest-api-client.models.fx_executed_rate.FXExecutedRate.from_dictionary(dictionary.get('fxExecutedDetail')) if dictionary.get('fxExecutedDetail') else None
        unapplied_reason = dictionary.get('unappliedReason')

        # Return an object of this model
        return cls(transaction_id,
                   timestamp,
                   transaction_type,
                   amount,
                   movement_type,
                   amount_deposited_by_user,
                   amount_deposited_to_merchant,
                   deposit_country,
                   deposit_date,
                   user_id,
                   transaction_status,
                   statement_details,
                   deposit_reference,
                   fx_executed_detail,
                   unapplied_reason)





# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.transaction_id
import earthport-rest-api-client.models.financial_transaction_status
import earthport-rest-api-client.models.monetary_value
import earthport-rest-api-client.models.statement_detail

class GenericTransaction(object):

    """Implementation of the 'GenericTransaction' model.

    A generic financial transaction used to represent different types of
    transactions in the EPS system that do not have their own specific
    mappings in the schema.

    Attributes:
        transaction_id (TransactionID): Transaction ID type which contains
            both the unique Earthport transaction ID and the merchant supplied
            transaction ID.
        timestamp (string): TODO: type description here.
        transaction_type (string): TODO: type description here.
        transaction_status (FinancialTransactionStatus): Additional important
            status information for specific transaction types.
        amount (MonetaryValue): Represents a monetary value containing a
            decimal amount value along with a currency code. The currency code
            is a three letter ISO 4217 code. E.g. GBP for British sterling
            pounds.
        movement_type (MoneyMovementTypeEnum): Specifies whether a money
            movement is a debit or credit
        statement_details (list of StatementDetail): TODO: type description
            here.
        description (string): Any additional information about the
            transaction.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "transaction_id":'transactionID',
        "timestamp":'timestamp',
        "transaction_type":'transactionType',
        "amount":'amount',
        "movement_type":'movementType',
        "transaction_status":'transactionStatus',
        "statement_details":'statementDetails',
        "description":'description'
    }

    def __init__(self,
                 transaction_id=None,
                 timestamp=None,
                 transaction_type=None,
                 amount=None,
                 movement_type=None,
                 transaction_status=None,
                 statement_details=None,
                 description=None):
        """Constructor for the GenericTransaction class"""

        # Initialize members of the class
        self.transaction_id = transaction_id
        self.timestamp = timestamp
        self.transaction_type = transaction_type
        self.transaction_status = transaction_status
        self.amount = amount
        self.movement_type = movement_type
        self.statement_details = statement_details
        self.description = description


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        transaction_id = earthport-rest-api-client.models.transaction_id.TransactionID.from_dictionary(dictionary.get('transactionID')) if dictionary.get('transactionID') else None
        timestamp = dictionary.get('timestamp')
        transaction_type = dictionary.get('transactionType')
        amount = earthport-rest-api-client.models.monetary_value.MonetaryValue.from_dictionary(dictionary.get('amount')) if dictionary.get('amount') else None
        movement_type = dictionary.get('movementType')
        transaction_status = earthport-rest-api-client.models.financial_transaction_status.FinancialTransactionStatus.from_dictionary(dictionary.get('transactionStatus')) if dictionary.get('transactionStatus') else None
        statement_details = None
        if dictionary.get('statementDetails') != None:
            statement_details = list()
            for structure in dictionary.get('statementDetails'):
                statement_details.append(earthport-rest-api-client.models.statement_detail.StatementDetail.from_dictionary(structure))
        description = dictionary.get('description')

        # Return an object of this model
        return cls(transaction_id,
                   timestamp,
                   transaction_type,
                   amount,
                   movement_type,
                   transaction_status,
                   statement_details,
                   description)





# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.additional_field_with_validator
import earthport-rest-api-client.models.additional_field_with_values

class AdditionalFieldsList(object):

    """Implementation of the 'additionalFieldsList' model.

    Additional fields will be one of two types; free text or list options.
    'additionalFieldWithValues' gives a list of acceptable responses.
    'additionalFieldWithValidator' is a free text response.

    Attributes:
        additional_field_with_validator (list of
            AdditionalFieldWithValidator): TODO: type description here.
        additional_field_with_values (list of AdditionalFieldWithValues):
            TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "additional_field_with_validator":'additionalFieldWithValidator',
        "additional_field_with_values":'additionalFieldWithValues'
    }

    def __init__(self,
                 additional_field_with_validator=None,
                 additional_field_with_values=None):
        """Constructor for the AdditionalFieldsList class"""

        # Initialize members of the class
        self.additional_field_with_validator = additional_field_with_validator
        self.additional_field_with_values = additional_field_with_values


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        additional_field_with_validator = None
        if dictionary.get('additionalFieldWithValidator') != None:
            additional_field_with_validator = list()
            for structure in dictionary.get('additionalFieldWithValidator'):
                additional_field_with_validator.append(earthport-rest-api-client.models.additional_field_with_validator.AdditionalFieldWithValidator.from_dictionary(structure))
        additional_field_with_values = None
        if dictionary.get('additionalFieldWithValues') != None:
            additional_field_with_values = list()
            for structure in dictionary.get('additionalFieldWithValues'):
                additional_field_with_values.append(earthport-rest-api-client.models.additional_field_with_values.AdditionalFieldWithValues.from_dictionary(structure))

        # Return an object of this model
        return cls(additional_field_with_validator,
                   additional_field_with_values)





# -*- coding: utf-8 -*-


class IndividualName(object):

    """Implementation of the 'IndividualName' model.

    The 'givenNames' attribute is mandatory. This is a space separated list of
    names (not including the family name). 
    You should supply names and not initials (wherever possible). See examples
    below. 
    The 'familyName' attribute is mandatory. This contains the single family
    name. See examples below. 
    *Example1 - a western citizen from a country which uses the common western
    naming convention(such as US, GB, FR, CA, DE etc...)*
      
        Name = "John Michael Smith", 
      
        givenNames="John Michael" and familyName="Smith"
    *Example2 - a citizen from a country which uses the eastern name order
    where the family name comes first, followed by their given names (such as
    Hungary, China, Japan, Korea, Singapore, Taiwan, Vietnam etc...)* 
        Name = "Máo Zédÿng", 
      
        giveNames="Zédÿng" and familyName="Máo" 
        Name = "Hidetoshi Nakata", 
      
        givenNames="Nakata" and familyName="Hidetoshi"
        Name = "Ferenc Puskás", 
      
        giveNames="Puskás" and familyName="Ferenc"
    *Example3 - middle east names* 
      
        Name= "Mohammed bin Rashid bin Saeed Al-Maktoum", 
      
        givenNames="Mohammed bin Rashid bin Saeed" and familName="Al-Maktoum"
    *Example4 - single names, such as in Indonesia* 
      
        Name="Suharto", 
      
        givenNames="Suharto" and familyName="Suharto".

    Attributes:
        family_name (string): The family name component of an individual's
            identity. The length of this field is limited to 1024 bytes. 1024
            bytes can hold 1024 normal English characters.
        given_names (string): The given names component of an individual's
            identity. For detailed examples see documentation for type
            IndividualName. The length of this field is limited to 1024 bytes.
            1024 bytes can hold 1024 normal English characters.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "family_name":'familyName',
        "given_names":'givenNames'
    }

    def __init__(self,
                 family_name=None,
                 given_names=None):
        """Constructor for the IndividualName class"""

        # Initialize members of the class
        self.family_name = family_name
        self.given_names = given_names


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        family_name = dictionary.get('familyName')
        given_names = dictionary.get('givenNames')

        # Return an object of this model
        return cls(family_name,
                   given_names)





# -*- coding: utf-8 -*-


class GetPayoutRequiredDataForCountryCurrency(object):

    """Implementation of the 'getPayoutRequiredDataForCountryCurrency' model.

    TODO: type model description here.

    Attributes:
        beneficiary_identity_entity (IdentityEntityEnum): Supported identity
            entity types.
        country_code (string): Valid supported ISO 3166 2-character country
            code.
        currency_code (string): Valid supported ISO 4217 3-character currency
            code.
        locale (string): Supports a comma separated list of locales. for
            example en_GB, en_US in order of preferred locale.
        service_level (ServiceLevelEnum): Supported service levels for a
            payout request (standard or express).

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "country_code":'countryCode',
        "currency_code":'currencyCode',
        "beneficiary_identity_entity":'beneficiaryIdentityEntity',
        "locale":'locale',
        "service_level":'serviceLevel'
    }

    def __init__(self,
                 country_code=None,
                 currency_code=None,
                 beneficiary_identity_entity=None,
                 locale=None,
                 service_level=None):
        """Constructor for the GetPayoutRequiredDataForCountryCurrency class"""

        # Initialize members of the class
        self.beneficiary_identity_entity = beneficiary_identity_entity
        self.country_code = country_code
        self.currency_code = currency_code
        self.locale = locale
        self.service_level = service_level


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        country_code = dictionary.get('countryCode')
        currency_code = dictionary.get('currencyCode')
        beneficiary_identity_entity = dictionary.get('beneficiaryIdentityEntity')
        locale = dictionary.get('locale')
        service_level = dictionary.get('serviceLevel')

        # Return an object of this model
        return cls(country_code,
                   currency_code,
                   beneficiary_identity_entity,
                   locale,
                   service_level)





# -*- coding: utf-8 -*-

class HttpCallBack(object):

    """An interface for  the callback to be called before and after the
    HTTP call for an endpoint is made.

    This class should not be instantiated but should be used as a base class
    for HttpCallBack classes.

    """

    def on_before_request(self,
                          request):
        """The controller will call this method before making the HttpRequest.

        Args:
            request (HttpRequest): The request object which will be sent
                to the HttpClient to be executed.
        """
        raise NotImplementedError("This method has not been implemented.")

    def on_after_response(self,
                          context):
        """The controller will call this method after making the HttpRequest.

        Args:
            context (HttpContext): The HttpContext of the API call.
        """
        raise NotImplementedError("This method has not been implemented.")



# -*- coding: utf-8 -*-

from .base_controller import BaseController
from ..api_helper import APIHelper
from ..configuration import Configuration
from ..http.auth.custom_header_auth import CustomHeaderAuth
from ..models.statement import Statement
from ..exceptions.api_exception import APIException

class StatementsController(BaseController):

    """A Controller to access Endpoints in the earthport-rest-api-client API."""


    def get_statement(self,
                      managed_merchant_name=None,
                      currency=None,
                      start_date_time=None,
                      end_date_time=None,
                      sort_order=None,
                      offset=None,
                      page_size=None):
        """Does a GET request to /statements.

        Retrieves the statement of a merchant account.

        Args:
            managed_merchant_name (string, optional): The name of managed
                merchant registered on EarthPort
            currency (string, optional): currency
            start_date_time (string, optional): startDateTime in
                yyyyy-MM-ddTHH:mm:ssZ
            end_date_time (string, optional): endDateTime in
                yyyyy-MM-ddTHH:mm:ssZ
            sort_order (SortOrderEnum, optional): Sort in either ascending or
                descending order
            offset (int, optional): This is used for pagination of resultsets.
                0-based starting offset of the page with respect to the entire
                resultset.
            page_size (int, optional): This is used for pagination of
                resultsets. Number of items per page to return. If empty the
                maximum allowable (25) number of records will be returned.

        Returns:
            Statement: Response from the API. Statement succesfully
                retrieved.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.get_base_uri()
        _query_builder += '/statements'
        _query_parameters = {
            'managedMerchantName': managed_merchant_name,
            'currency': currency,
            'startDateTime': start_date_time,
            'endDateTime': end_date_time,
            'sortOrder': sort_order,
            'offset': offset,
            'pageSize': page_size
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 400:
            raise APIException('The requested operation could not be performed. Input Request is invalid or incorrect.', _context)
        elif _context.response.status_code == 401:
            raise APIException('Unauthorized - Invalid API Key and Token.', _context)
        elif _context.response.status_code == 500:
            raise APIException('An internal error has occurred in the Earthport payment platform.', _context)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, Statement.from_dictionary)



# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.individual_identity
import earthport-rest-api-client.models.legal_entity_identity
import earthport-rest-api-client.models.unstructured_identity
import earthport-rest-api-client.models.additional_data

class Identity(object):

    """Implementation of the 'Identity' model.

    Represents the identity of an individual or legal entity. You must specify
    one of either an individual identity or legal entity identity or
    unstructured identity.

    Attributes:
        individual_identity (IndividualIdentity): The identity of an
            individual. The 'name' attribute is mandatory for an individual.
            You must supply at least identification entry or one birth
            information entry or one address entry.
        legal_entity_identity (LegalEntityIdentity): The identity of a legal
            entity. The 'legalEntityName' is mandatory. You must supply one of
            'legalEntityRegistration' or 'address'.
        unstructured_identity (list of UnstructuredIdentity): TODO: type
            description here.
        additional_data (list of AdditionalData): TODO: type description
            here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "individual_identity":'individualIdentity',
        "legal_entity_identity":'legalEntityIdentity',
        "unstructured_identity":'unstructuredIdentity',
        "additional_data":'additionalData'
    }

    def __init__(self,
                 individual_identity=None,
                 legal_entity_identity=None,
                 unstructured_identity=None,
                 additional_data=None):
        """Constructor for the Identity class"""

        # Initialize members of the class
        self.individual_identity = individual_identity
        self.legal_entity_identity = legal_entity_identity
        self.unstructured_identity = unstructured_identity
        self.additional_data = additional_data


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        individual_identity = earthport-rest-api-client.models.individual_identity.IndividualIdentity.from_dictionary(dictionary.get('individualIdentity')) if dictionary.get('individualIdentity') else None
        legal_entity_identity = earthport-rest-api-client.models.legal_entity_identity.LegalEntityIdentity.from_dictionary(dictionary.get('legalEntityIdentity')) if dictionary.get('legalEntityIdentity') else None
        unstructured_identity = None
        if dictionary.get('unstructuredIdentity') != None:
            unstructured_identity = list()
            for structure in dictionary.get('unstructuredIdentity'):
                unstructured_identity.append(earthport-rest-api-client.models.unstructured_identity.UnstructuredIdentity.from_dictionary(structure))
        additional_data = None
        if dictionary.get('additionalData') != None:
            additional_data = list()
            for structure in dictionary.get('additionalData'):
                additional_data.append(earthport-rest-api-client.models.additional_data.AdditionalData.from_dictionary(structure))

        # Return an object of this model
        return cls(individual_identity,
                   legal_entity_identity,
                   unstructured_identity,
                   additional_data)





# -*- coding: utf-8 -*-


class UserID(object):

    """Implementation of the 'UserID' model.

    This group consists of all possible user identifier types. The 'epUserID'
    field is a unique identifier for a merchant and is the equivalent of a
    Virtual Account Number (VAN). The 'merchantUserID' is a merchant specified
    identifier for an individual or company that an account was set up for.
    The 'epUserID', 'merchantUserID' or both 'epUserID' and 'merchantUserID'
    can be supplied. A mapping will be performed to retrieve the merchant user
    ID from the supplied EP user ID and vice versa. If both the 'epUserID' and
    'merchantUserID' are supplied, a check will be performed to ensure that
    the two are mapped. If the two provided fields are not mapped, then a
    validation error code will be returned. At least one of the fields must be
    populated.

    Attributes:
        ep_user_id (long|int): user’s unique id generated by EarthPort. This
            is also called the VAN (Virtual Account Number.
        merchant_user_id (string): A unique reference for the merchant that
            identifies the person or company on behalf of which this account
            was set up. This needs to be used to reference KYC data held by
            the merchant (amongst other things). This is often a unique
            username or reference allocated by the merchant at user
            registration time.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "ep_user_id":'epUserID',
        "merchant_user_id":'merchantUserID'
    }

    def __init__(self,
                 ep_user_id=None,
                 merchant_user_id=None):
        """Constructor for the UserID class"""

        # Initialize members of the class
        self.ep_user_id = ep_user_id
        self.merchant_user_id = merchant_user_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        ep_user_id = dictionary.get('epUserID')
        merchant_user_id = dictionary.get('merchantUserID')

        # Return an object of this model
        return cls(ep_user_id,
                   merchant_user_id)





# -*- coding: utf-8 -*-

from .decorators import lazy_property
from .configuration import Configuration
from .controllers.quotes_controller import QuotesController
from .controllers.balances_controller import BalancesController
from .controllers.payments_controller import PaymentsController
from .controllers.beneficiary_bank_accounts_controller import BeneficiaryBankAccountsController
from .controllers.authentication_controller import AuthenticationController
from .controllers.users_controller import UsersController
from .controllers.transactions_controller import TransactionsController
from .controllers.statements_controller import StatementsController
from .controllers.settlement_calendars_controller import SettlementCalendarsController

class EarthportRestApiClientClient(object):

    config = Configuration

    @lazy_property
    def quotes(self):
        return QuotesController()

    @lazy_property
    def balances(self):
        return BalancesController()

    @lazy_property
    def payments(self):
        return PaymentsController()

    @lazy_property
    def beneficiary_bank_accounts(self):
        return BeneficiaryBankAccountsController()

    @lazy_property
    def authentication(self):
        return AuthenticationController()

    @lazy_property
    def users(self):
        return UsersController()

    @lazy_property
    def transactions(self):
        return TransactionsController()

    @lazy_property
    def statements(self):
        return StatementsController()

    @lazy_property
    def settlement_calendars(self):
        return SettlementCalendarsController()


    def __init__(self, 
                 authorization = None):
        if authorization != None:
            Configuration.authorization = authorization





# -*- coding: utf-8 -*-

import re
import sys
import datetime
import calendar
import email.utils as eut
from time import mktime

import jsonpickle
import dateutil.parser
from requests.utils import quote

class APIHelper(object):

    """A Helper Class for various functions associated with API Calls.

    This class contains static methods for operations that need to be
    performed during API requests. All of the methods inside this class are
    static methods, there is no need to ever initialise an instance of this
    class.

    """

    @staticmethod
    def merge_dicts(dict1, dict2):
        """Merges two dictionaries into one as a shallow copy.

        Args:
            dict1 (dict): The first dictionary.
            dict2 (dict): The second dictionary.

        Returns:
            dict: A dictionary containing key value pairs
            from both the argument dictionaries. In the case
            of a key conflict, values from dict2 are used
            and those from dict1 are lost.

        """
        temp = dict1.copy()
        temp.update(dict2)
        return temp

    @staticmethod
    def json_serialize(obj):
        """JSON Serialization of a given object.

        Args:
            obj (object): The object to serialise.

        Returns:
            str: The JSON serialized string of the object.

        """
        if obj is None:
            return None

        # Resolve any Names if it's one of our objects that needs to have this called on
        if isinstance(obj, list):
            value = list()
            for item in obj:
                if hasattr(item, "_names"):
                    value.append(APIHelper.to_dictionary(item))
                else:
                    value.append(item)
            obj = value
        else:
            if hasattr(obj, "_names"):
                obj = APIHelper.to_dictionary(obj)

        return jsonpickle.encode(obj, False)

    @staticmethod
    def json_deserialize(json, unboxing_function=None):
        """JSON Deerialization of a given string.

        Args:
            json (str): The JSON serialized string to deserialize.

        Returns:
            dict: A dictionary representing the data contained in the
                JSON serialized string.

        """
        if json is None:
            return None

        try:
            decoded = jsonpickle.decode(json)
        except:
            return json

        if unboxing_function is None:
            return decoded
        elif isinstance(decoded, list):
            return [unboxing_function(element) for element in decoded]
        else:
            return unboxing_function(decoded)

    @staticmethod
    def serialize_array(key, array, formatting="indexed"):
        """Converts an array parameter to a list of key value tuples.

        Args:
            key (str): The name of the parameter.
            array (list): The value of the parameter.
            formatting (str): The type of key formatting expected.

        Returns:
            list: A list with key value tuples for the array elements.

        """
        tuples = []

        if sys.version_info[0] < 3:
            serializable_types = (str, int, long, float, bool, datetime.date, APIHelper.CustomDate)
        else:
            serializable_types = (str, int, float, bool, datetime.date, APIHelper.CustomDate)

        if isinstance(array[0], serializable_types):
            if formatting is "unindexed":
                tuples += [("{0}[]".format(key), element) for element in array]
            elif formatting is "indexed":
                tuples += [("{0}[{1}]".format(key, index), element) for index, element in enumerate(array)]
            elif formatting is "plain":
                tuples += [(key, element) for element in array]
            else:
                raise ValueError("Invalid format provided.")
        else:
            tuples += [("{0}[{1}]".format(key, index), element) for index, element in enumerate(array)]

        return tuples

    @staticmethod
    def append_url_with_template_parameters(url,
                                            parameters):
        """Replaces template parameters in the given url.

        Args:
            url (str): The query url string to replace the template parameters.
            parameters (dict): The parameters to replace in the url.

        Returns:
            str: URL with replaced parameters.

        """
        # Parameter validation
        if url is None:
            raise ValueError("URL is None.")
        if parameters is None:
            return url

        # Iterate and replace parameters
        for key in parameters:
            element = parameters[key]
            replace_value = ""

            # Load parameter value
            if element is None:
                replace_value = ""
            elif isinstance(element, list):
                replace_value = "/".join(quote(str(x), safe='') for x in element)
            else:
                replace_value = quote(str(element), safe='')

            url = url.replace('{{{0}}}'.format(key), str(replace_value))

        return url

    @staticmethod
    def append_url_with_query_parameters(url,
                                         parameters,
                                         array_serialization="indexed"):
        """Adds query parameters to a URL.

        Args:
            url (str): The URL string.
            parameters (dict): The query parameters to add to the URL.
            array_serialization (str): The format of array parameter serialization.

        Returns:
            str: URL with added query parameters.

        """
        # Parameter validation
        if url is None:
            raise ValueError("URL is None.")
        if parameters is None:
            return url

        for key, value in parameters.items():
            seperator = '&' if '?' in url else '?'
            if value is not None:
                if isinstance(value, list):
                    value = [element for element in value if element]
                    if array_serialization is "csv":
                        url += "{0}{1}={2}".format(seperator, key,
                            ",".join(quote(str(x), safe='') for x in value))
                    elif array_serialization is "psv":
                        url += "{0}{1}={2}".format(seperator, key,
                            "|".join(quote(str(x), safe='') for x in value))
                    elif array_serialization is "tsv":
                        url += "{0}{1}={2}".format(seperator, key,
                            "\t".join(quote(str(x), safe='') for x in value))
                    else:
                        url += "{0}{1}".format(seperator,
                            "&".join(("{0}={1}".format(k, quote(str(v), safe='')))
                                for k, v in APIHelper.serialize_array(key, value, array_serialization)))
                else:
                    url += "{0}{1}={2}".format(seperator, key, quote(str(value), safe=''))

        return url

    @staticmethod
    def clean_url(url):
        """Validates and processes the given query Url to clean empty slashes.

        Args:
            url (str): The given query Url to process.

        Returns:
            str: Clean Url as string.

        """
        # Ensure that the urls are absolute
        regex = "^https?://[^/]+"
        match = re.match(regex, url)
        if match is None:
            raise ValueError('Invalid Url format.')

        protocol = match.group(0)
        index = url.find('?')
        query_url = url[len(protocol): index if index != -1 else None]
        query_url = re.sub("//+", "/", query_url)
        parameters = url[index:] if index != -1 else ""

        return protocol + query_url + parameters

    @staticmethod
    def form_encode_parameters(form_parameters,
                               array_serialization="indexed"):
        """Form encodes a dictionary of form parameters

        Args:
            form_parameters (dictionary): The given dictionary which has
            atleast one model to form encode.
            array_serialization (str): The format of array parameter serialization.

        Returns:
            dict: A dictionary of form encoded properties of the model.

        """
        encoded = []

        for key, value in form_parameters.items():
            encoded += APIHelper.form_encode(value, key, array_serialization)

        return encoded

    @staticmethod
    def form_encode(obj,
                    instance_name,
                    array_serialization="indexed"):
        """Encodes a model in a form-encoded manner such as person[Name]

        Args:
            obj (object): The given Object to form encode.
            instance_name (string): The base name to appear before each entry
                for this object.
            array_serialization (string): The format of array parameter serialization.

        Returns:
            dict: A dictionary of form encoded properties of the model.

        """
        retval = []

        # If we received an object, resolve it's field names.
        if hasattr(obj, "_names"):
            obj = APIHelper.to_dictionary(obj)

        if obj is None:
            return []
        elif isinstance(obj, list):
            for element in APIHelper.serialize_array(instance_name, obj, array_serialization):
                retval += APIHelper.form_encode(element[1], element[0], array_serialization)
        elif isinstance(obj, dict):
            for item in obj:
                retval += APIHelper.form_encode(obj[item], instance_name + "[" + item + "]", array_serialization)
        else:
            retval.append((instance_name, obj))

        return retval

    @staticmethod
    def to_dictionary(obj):
        """Creates a dictionary representation of a class instance. The
        keys are taken from the API description and may differ from language
        specific variable names of properties.

        Args:
            obj: The object to be converted into a dictionary.

        Returns:
            dictionary: A dictionary form of the model with properties in
            their API formats.

        """
        dictionary = dict()

        # Loop through all properties in this model
        for name in obj._names:
            value = getattr(obj, name)
            if isinstance(value, list):
                # Loop through each item
                dictionary[obj._names[name]] = list()
                for item in value:
                    dictionary[obj._names[name]].append(APIHelper.to_dictionary(item) if hasattr(item, "_names") else item)
            elif isinstance(value, dict):
                # Loop through each item
                dictionary[obj._names[name]] = dict()
                for key in value:
                    dictionary[obj._names[name]][key] = APIHelper.to_dictionary(value[key]) if hasattr(value[key], "_names") else value[key]
            else:
                dictionary[obj._names[name]] = APIHelper.to_dictionary(value) if hasattr(value, "_names") else value

        # Return the result
        return dictionary

    @staticmethod
    def when_defined(func, value):
        return func(value) if value else None

    class CustomDate(object):

        """ A base class for wrapper classes of datetime.

        This class contains methods which help in
        appropriate serialization of datetime objects.

        """

        def __init__(self, dtime, value=None):
            self.datetime = dtime
            if not value:
                self.value = self.from_datetime(dtime)
            else:
                self.value = value

        def __str__(self):
            return self.value

        def __getstate__(self):
            return self.value

        def __setstate__(self, state):
            pass

    class HttpDateTime(CustomDate):

        """ A wrapper class for datetime to support HTTP date format."""

        @classmethod
        def from_datetime(cls, date_time):
            return eut.formatdate(timeval=mktime(date_time.timetuple()),
                                  localtime=False, usegmt=True)

        @classmethod
        def from_value(cls, value):
            dtime = datetime.datetime.fromtimestamp(eut.mktime_tz(eut.parsedate_tz(value)))
            return cls(dtime, value)

    class UnixDateTime(CustomDate):

        """ A wrapper class for datetime to support Unix date format."""

        def __str__(self):
            return str(self.value)

        @classmethod
        def from_datetime(cls, date_time):
            return calendar.timegm(date_time.utctimetuple())

        @classmethod
        def from_value(cls, value):
            dtime = datetime.datetime.utcfromtimestamp(float(value))
            return cls(dtime, float(value))

    class RFC3339DateTime(CustomDate):

        """ A wrapper class for datetime to support Rfc 3339 format."""

        @classmethod
        def from_datetime(cls, date_time):
            return date_time.isoformat()

        @classmethod
        def from_value(cls, value):
            dtime = dateutil.parser.parse(value)
            return cls(dtime, value)



# -*- coding: utf-8 -*-

class SortOrderEnum(object):

    """Implementation of the 'sortOrder' enum.

    TODO: type enum description here.

    Attributes:
        DESC: TODO: type description here.
        ASC: TODO: type description here.

    """

    DESC = 'DESC'

    ASC = 'ASC'




# -*- coding: utf-8 -*-

from .api_helper import APIHelper


class Configuration(object):

    """A class used for configuring the SDK by a user.

    This class need not be instantiated and all properties and methods
    are accessible without instance creation.

    """

    # Set the array parameter serialization method
    # (allowed: indexed, unindexed, plain, csv, tsv, psv)
    array_serialization = "indexed"

    # An enum for SDK environments
    class Environment(object):
        # Production server.
        PRODUCTION = 0
        # Sandbox is used for both sandbox testing and customer UAT.
        SANDBOX = 1
        # Customer integration is used by existing clients who need to test new functionality before it is released onto sandbox and production.
        CUSTOMER_INTEGRATION = 2

    # An enum for API servers
    class Server(object):
        DEFAULT = 0
        AUTH = 1

    # The environment in which the SDK is running
    environment = Environment.SANDBOX

    # TODO: Set an appropriate value
    authorization = None


    # All the environments the SDK can run in
    environments = {
        Environment.PRODUCTION: {
            Server.DEFAULT: 'https://api.earthport.com/v1',
            Server.AUTH: 'https://api.earthport.com',
        },
        Environment.SANDBOX: {
            Server.DEFAULT: 'https://api-sandbox.earthport.com/v1',
            Server.AUTH: 'https://api-sandbox.earthport.com',
        },
        Environment.CUSTOMER_INTEGRATION: {
            Server.DEFAULT: 'https://api-integration.earthport.com/v1',
            Server.AUTH: 'https://api-integration.earthport.com',
        },
    }

    @classmethod
    def get_base_uri(cls, server=Server.DEFAULT):
        """Generates the appropriate base URI for the environment and the server.

        Args:
            server (Configuration.Server): The server enum for which the base URI is required.

        Returns:
            String: The base URI.

        """
        return cls.environments[cls.environment][server]



# -*- coding: utf-8 -*-


class PayerAdditionalData(object):

    """Implementation of the 'PayerAdditionalData' model.

    Represents a set of name value pairs that can be supplied with the
    Identity information. The keys will be validated on the server side
    against a list of valid types that are accepted. See the 'API Solution
    Guide' for further details. Both the key and the value are required if
    adding additional data. The length of the additionalDataKey field is
    currently restricted to 50 bytes and will be truncated if the value is too
    long. The length of the additionalDataValue field is currently restricted
    to 254 bytes and will be truncated if the value is too long.

    Attributes:
        additional_data_key (string): TODO: type description here.
        additional_data_value (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "additional_data_key":'additionalDataKey',
        "additional_data_value":'additionalDataValue'
    }

    def __init__(self,
                 additional_data_key=None,
                 additional_data_value=None):
        """Constructor for the PayerAdditionalData class"""

        # Initialize members of the class
        self.additional_data_key = additional_data_key
        self.additional_data_value = additional_data_value


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        additional_data_key = dictionary.get('additionalDataKey')
        additional_data_value = dictionary.get('additionalDataValue')

        # Return an object of this model
        return cls(additional_data_key,
                   additional_data_value)





# -*- coding: utf-8 -*-


class BirthInformation(object):

    """Implementation of the 'BirthInformation' model.

    The group consists of elements that define birth information for an
    individual.

    Attributes:
        city_of_birth (string): A line of address information. The length of
            this field is limited to 254 bytes. This value will be truncated
            if it is too long.
        country_of_birth (string): Valid supported ISO 3166 2-character
            country code.
        date_of_birth (string): Valid ISO 8601 date format YYYY-MM-DD.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "country_of_birth":'countryOfBirth',
        "date_of_birth":'dateOfBirth',
        "city_of_birth":'cityOfBirth'
    }

    def __init__(self,
                 country_of_birth=None,
                 date_of_birth=None,
                 city_of_birth=None):
        """Constructor for the BirthInformation class"""

        # Initialize members of the class
        self.city_of_birth = city_of_birth
        self.country_of_birth = country_of_birth
        self.date_of_birth = date_of_birth


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        country_of_birth = dictionary.get('countryOfBirth')
        date_of_birth = dictionary.get('dateOfBirth')
        city_of_birth = dictionary.get('cityOfBirth')

        # Return an object of this model
        return cls(country_of_birth,
                   date_of_birth,
                   city_of_birth)





# -*- coding: utf-8 -*-

class ActionEnum(object):

    """Implementation of the 'action' enum.

    TODO: type enum description here.

    Attributes:
        VALIDATE: TODO: type description here.

    """

    VALIDATE = 'validate'




# -*- coding: utf-8 -*-

class BeneficiaryBankAccountStatusEnum(object):

    """Implementation of the 'BeneficiaryBankAccountStatus' enum.

    Type which defines a beneficiary bank account status. (ie. active or
    deleted).

    Attributes:
        ACTIVE: TODO: type description here.
        INACTIVE: TODO: type description here.

    """

    ACTIVE = 'ACTIVE'

    INACTIVE = 'INACTIVE'




# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.user
import earthport-rest-api-client.models.bank_account
import earthport-rest-api-client.models.payment

class CreatePaymentRequest(object):

    """Implementation of the 'CreatePaymentRequest' model.

    TODO: type model description here.

    Attributes:
        user (User): A user Object.
        bank_account (BankAccount): The beneficiary bank account Object.
        payment (Payment): Beneficiary Bank account payment.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "user":'user',
        "bank_account":'bankAccount',
        "payment":'payment'
    }

    def __init__(self,
                 user=None,
                 bank_account=None,
                 payment=None):
        """Constructor for the CreatePaymentRequest class"""

        # Initialize members of the class
        self.user = user
        self.bank_account = bank_account
        self.payment = payment


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        user = earthport-rest-api-client.models.user.User.from_dictionary(dictionary.get('user')) if dictionary.get('user') else None
        bank_account = earthport-rest-api-client.models.bank_account.BankAccount.from_dictionary(dictionary.get('bankAccount')) if dictionary.get('bankAccount') else None
        payment = earthport-rest-api-client.models.payment.Payment.from_dictionary(dictionary.get('payment')) if dictionary.get('payment') else None

        # Return an object of this model
        return cls(user,
                   bank_account,
                   payment)





# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.beneficiary_bank_account_group

class BeneficiaryBankAccountGroupsList(object):

    """Implementation of the 'BeneficiaryBankAccountGroupsList' model.

    This type defines a list of bank account data groups. Each group is
    normally represented as a row on the UI.

    Attributes:
        beneficiary_bank_account_field_group (list of
            BeneficiaryBankAccountGroup): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "beneficiary_bank_account_field_group":'beneficiaryBankAccountFieldGroup'
    }

    def __init__(self,
                 beneficiary_bank_account_field_group=None):
        """Constructor for the BeneficiaryBankAccountGroupsList class"""

        # Initialize members of the class
        self.beneficiary_bank_account_field_group = beneficiary_bank_account_field_group


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        beneficiary_bank_account_field_group = None
        if dictionary.get('beneficiaryBankAccountFieldGroup') != None:
            beneficiary_bank_account_field_group = list()
            for structure in dictionary.get('beneficiaryBankAccountFieldGroup'):
                beneficiary_bank_account_field_group.append(earthport-rest-api-client.models.beneficiary_bank_account_group.BeneficiaryBankAccountGroup.from_dictionary(structure))

        # Return an object of this model
        return cls(beneficiary_bank_account_field_group)





# -*- coding: utf-8 -*-


class FXTicketID(object):

    """Implementation of the 'FXTicketID' model.

    The unique FX Ticket ID generated by the Earthport payment system.

    Attributes:
        ticket_id (int): Generic entity identity.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "ticket_id":'ticketID'
    }

    def __init__(self,
                 ticket_id=None):
        """Constructor for the FXTicketID class"""

        # Initialize members of the class
        self.ticket_id = ticket_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        ticket_id = dictionary.get('ticketID')

        # Return an object of this model
        return cls(ticket_id)





# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.additional_fields_list
import earthport-rest-api-client.models.identity_restriction

class PurposeOfPaymentUsageRestrictions(object):

    """Implementation of the 'purposeOfPaymentUsageRestrictions' model.

    Usage restrictions apply where a specified code is only acceptable for a
    given type of payer or beneficiary. This attribute indicates whether the
    code can be used for Individuals and/or Legal Entities, for both payer and
    beneficiary parties. Additional field specifications identify further data
    that is required, given the chosen Purpose of Payment.

    Attributes:
        additional_fields_list (AdditionalFieldsList): Additional fields will
            be one of two types; free text or list options.
            'additionalFieldWithValues' gives a list of acceptable responses.
            'additionalFieldWithValidator' is a free text response.
        beneficiary (IdentityRestriction): TODO: type description here.
        originator (IdentityRestriction): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "additional_fields_list":'additionalFieldsList',
        "beneficiary":'beneficiary',
        "originator":'originator'
    }

    def __init__(self,
                 additional_fields_list=None,
                 beneficiary=None,
                 originator=None):
        """Constructor for the PurposeOfPaymentUsageRestrictions class"""

        # Initialize members of the class
        self.additional_fields_list = additional_fields_list
        self.beneficiary = beneficiary
        self.originator = originator


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        additional_fields_list = earthport-rest-api-client.models.additional_fields_list.AdditionalFieldsList.from_dictionary(dictionary.get('additionalFieldsList')) if dictionary.get('additionalFieldsList') else None
        beneficiary = earthport-rest-api-client.models.identity_restriction.IdentityRestriction.from_dictionary(dictionary.get('beneficiary')) if dictionary.get('beneficiary') else None
        originator = earthport-rest-api-client.models.identity_restriction.IdentityRestriction.from_dictionary(dictionary.get('originator')) if dictionary.get('originator') else None

        # Return an object of this model
        return cls(additional_fields_list,
                   beneficiary,
                   originator)





# -*- coding: utf-8 -*-

from ..api_helper import APIHelper

class HttpRequest(object):

    """Information about an HTTP Request including its method, headers,
        parameters, URL, and Basic Auth details

    Attributes:
        http_method (HttpMethodEnum): The HTTP Method that this request should
            perform when called.
        headers (dict): A dictionary of headers (key : value) that should be
            sent along with the request.
        query_url (string): The URL that the request should be sent to.
        parameters (dict): A dictionary of parameters that are to be sent along
            with the request in the form body of the request

    """

    def __init__(self,
                 http_method,
                 query_url,
                 headers=None,
                 query_parameters=None,
                 parameters=None,
                 files=None):
        """Constructor for the HttpRequest class

        Args:
            http_method (HttpMethodEnum): The HTTP Method.
            query_url (string): The URL to send the request to.
            headers (dict, optional): The headers for the HTTP Request.
            query_parameters (dict, optional): Query parameters to add in the URL.
            parameters (dict, optional): Form or body parameters to be included in the body.
            files (dict, optional): Files to be sent with the request.

        """
        self.http_method = http_method
        self.query_url = query_url
        self.headers = headers
        self.query_parameters = query_parameters
        self.parameters = parameters
        self.files = files

    def add_header(self, name, value):
        """ Add a header to the HttpRequest.

        Args:
	        name (string): The name of the header.
            value (string): The value of the header.

        """
        self.headers[name] = value

    def add_parameter(self, name, value):
        """ Add a parameter to the HttpRequest.

        Args:
	        name (string): The name of the parameter.
            value (string): The value of the parameter.

        """
        self.parameters[name] = value

    def add_query_parameter(self, name, value):
        """ Add a query parameter to the HttpRequest.

        Args:
	        name (string): The name of the query parameter.
            value (string): The value of the query parameter.

        """
        self.query_url = APIHelper.append_url_with_query_parameters(self.query_url,
                                                                    {name:value})
        self.query_url = APIHelper.clean_url(self.query_url)



# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.purpose_of_payment_usage_restrictions

class PurposeOfPaymentCode(object):

    """Implementation of the 'purposeOfPaymentCode' model.

    This contains a specific Purpose of Payment option, consisting of a code
    and a human readable description.

    Attributes:
        code (string): TODO: type description here.
        description (string): TODO: type description here.
        purpose_of_payment_usage_restrictions
            (PurposeOfPaymentUsageRestrictions): Usage restrictions apply
            where a specified code is only acceptable for a given type of
            payer or beneficiary. This attribute indicates whether the code
            can be used for Individuals and/or Legal Entities, for both payer
            and beneficiary parties. Additional field specifications identify
            further data that is required, given the chosen Purpose of
            Payment.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "code":'code',
        "description":'description',
        "purpose_of_payment_usage_restrictions":'purposeOfPaymentUsageRestrictions'
    }

    def __init__(self,
                 code=None,
                 description=None,
                 purpose_of_payment_usage_restrictions=None):
        """Constructor for the PurposeOfPaymentCode class"""

        # Initialize members of the class
        self.code = code
        self.description = description
        self.purpose_of_payment_usage_restrictions = purpose_of_payment_usage_restrictions


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        code = dictionary.get('code')
        description = dictionary.get('description')
        purpose_of_payment_usage_restrictions = earthport-rest-api-client.models.purpose_of_payment_usage_restrictions.PurposeOfPaymentUsageRestrictions.from_dictionary(dictionary.get('purposeOfPaymentUsageRestrictions')) if dictionary.get('purposeOfPaymentUsageRestrictions') else None

        # Return an object of this model
        return cls(code,
                   description,
                   purpose_of_payment_usage_restrictions)





# -*- coding: utf-8 -*-


class CancelTransactionResponse(object):

    """Implementation of the 'Cancel TransactionResponse' model.

    Transaction Cancellation Response.

    Attributes:
        status (string): TODO: type description here.
        status_description (string): TODO: type description here.
        timestamp (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "status":'status',
        "status_description":'statusDescription',
        "timestamp":'timestamp'
    }

    def __init__(self,
                 status=None,
                 status_description=None,
                 timestamp=None):
        """Constructor for the CancelTransactionResponse class"""

        # Initialize members of the class
        self.status = status
        self.status_description = status_description
        self.timestamp = timestamp


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        status = dictionary.get('status')
        status_description = dictionary.get('statusDescription')
        timestamp = dictionary.get('timestamp')

        # Return an object of this model
        return cls(status,
                   status_description,
                   timestamp)





# -*- coding: utf-8 -*-

from .base_controller import BaseController
from ..api_helper import APIHelper
from ..configuration import Configuration
from ..http.auth.custom_header_auth import CustomHeaderAuth
from ..models.create_bulk_fx_quote_response import CreateBulkFXQuoteResponse
from ..models.get_indicative_fx_quote_response import GetIndicativeFXQuoteResponse
from ..models.create_fx_quote_response import CreateFXQuoteResponse
from ..exceptions.api_exception import APIException

class QuotesController(BaseController):

    """A Controller to access Endpoints in the earthport-rest-api-client API."""


    def create_bulk_fx_quote(self,
                             create_bulk_fx_quote_request=None):
        """Does a POST request to /quotes/bulk.

        Requests a bulk FX quote and creates a ticket for the quote.

        Args:
            create_bulk_fx_quote_request (list of CreateBulkFXQuoteRequest,
                optional): Bulk FX Quote Request.

        Returns:
            CreateBulkFXQuoteResponse: Response from the API. Quote
                succesfully retrieved.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.get_base_uri()
        _query_builder += '/quotes/bulk'
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(create_bulk_fx_quote_request))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 400:
            raise APIException('The requested operation could not be performed. Input Request is invalid or incorrect.', _context)
        elif _context.response.status_code == 401:
            raise APIException('Unauthorized - Invalid API Key and Token.', _context)
        elif _context.response.status_code == 500:
            raise APIException('An internal error has occurred in the Earthport payment platform.', _context)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, CreateBulkFXQuoteResponse.from_dictionary)

    def create_get_indicative_fx_quote(self,
                                       get_indicative_fx_quote_request=None):
        """Does a POST request to /quotes/indicative.

        Requests an  indicative quote

        Args:
            get_indicative_fx_quote_request (GetIndicativeFXQuoteRequest,
                optional): The request details to get an indicative FX quote.

        Returns:
            GetIndicativeFXQuoteResponse: Response from the API. Quote
                succesfully retrieved.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.get_base_uri()
        _query_builder += '/quotes/indicative'
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(get_indicative_fx_quote_request))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 400:
            raise APIException('The requested operation could not be performed. Input Request is invalid or incorrect.', _context)
        elif _context.response.status_code == 401:
            raise APIException('Unauthorized - Invalid API Key and Token.', _context)
        elif _context.response.status_code == 500:
            raise APIException('An internal error has occurred in the Earthport payment platform.', _context)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetIndicativeFXQuoteResponse.from_dictionary)

    def create_fx_quote(self,
                        user_id,
                        bank_id,
                        create_fx_quote_request=None,
                        id_type=None):
        """Does a POST request to /users/{userID}/bank-accounts/{bankID}/quotes.

        Requests a quote and creates a ticket for the quote.

        Args:
            user_id (string): The payer's unique id. It can be either VAN or
                merchant id.
            bank_id (string): Unique ID for the beneficiary bank account. It
                can be either earthport id or merchant id.
            create_fx_quote_request (CreateFXQuoteRequest, optional): The
                request details to get an FX quote and receive a unique Ticket
                ID with a time to live.
            id_type (IdTypeEnum, optional): idType for the path parameters.
                This allows you to specify either your own UIDs or Earthport
                generated UIDs. The Earthport generated UIDs will be used by
                default.

        Returns:
            CreateFXQuoteResponse: Response from the API. Quote succesfully
                retrieved.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.get_base_uri()
        _query_builder += '/users/{userID}/bank-accounts/{bankID}/quotes'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'userID': user_id,
            'bankID': bank_id
        })
        _query_parameters = {
            'idType': id_type
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(create_fx_quote_request))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 400:
            raise APIException('The requested operation could not be performed. Input Request is invalid or incorrect.', _context)
        elif _context.response.status_code == 401:
            raise APIException('Unauthorized - Invalid API Key and Token.', _context)
        elif _context.response.status_code == 500:
            raise APIException('An internal error has occurred in the Earthport payment platform.', _context)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, CreateFXQuoteResponse.from_dictionary)



# -*- coding: utf-8 -*-


class FinancialTransactionStatus(object):

    """Implementation of the 'FinancialTransactionStatus' model.

    Additional important status information for specific transaction types.

    Attributes:
        code (int): Numerical code of financial transaction status.
        description (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "code":'code',
        "description":'description'
    }

    def __init__(self,
                 code=None,
                 description=None):
        """Constructor for the FinancialTransactionStatus class"""

        # Initialize members of the class
        self.code = code
        self.description = description


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        code = dictionary.get('code')
        description = dictionary.get('description')

        # Return an object of this model
        return cls(code,
                   description)





# -*- coding: utf-8 -*-


class MonetaryValue(object):

    """Implementation of the 'MonetaryValue' model.

    Represents a monetary value containing a decimal amount value along with a
    currency code. The currency code is a three letter ISO 4217 code. E.g. GBP
    for British sterling pounds.

    Attributes:
        amount (float): TODO: type description here.
        currency (string): Valid supported ISO 4217 3-character currency
            code.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "amount":'amount',
        "currency":'currency'
    }

    def __init__(self,
                 amount=None,
                 currency=None):
        """Constructor for the MonetaryValue class"""

        # Initialize members of the class
        self.amount = amount
        self.currency = currency


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        amount = dictionary.get('amount')
        currency = dictionary.get('currency')

        # Return an object of this model
        return cls(amount,
                   currency)





from setuptools import setup, find_packages

# Try to convert markdown README to rst format for PyPI.
try:
    import pypandoc
    long_description = pypandoc.convert('README.md', 'rst')
except(IOError, ImportError):
    long_description = open('README.md').read()

setup(
    name='earthport-rest-api-client',
    version='1.0.0',
    description='This API supports all services required to make cross border payments using Earthport\'s network.',
    long_description=long_description,
    author='Earthport',
    author_email='support@earthport.com',
    url='https://www.earthport.com',
    packages=find_packages(),
    install_requires=[
        'requests>=2.9.1, <3.0',
        'jsonpickle>=0.7.1, <1.0',
        'cachecontrol>=0.11.7, <1.0',
        'python-dateutil>=2.5.3, <3.0'
    ]
)


# -*- coding: utf-8 -*-

class BeneficiaryIdentityEntityTypeEnum(object):

    """Implementation of the 'beneficiaryIdentityEntityType' enum.

    TODO: type enum description here.

    Attributes:
        LEGALENTITY: Legal Entity such as a company.
        INDIVIDUAL: Individual person.

    """

    LEGALENTITY = 'legalEntity'

    INDIVIDUAL = 'individual'




# -*- coding: utf-8 -*-


class IdentityRestriction(object):

    """Implementation of the 'identityRestriction' model.

    TODO: type model description here.

    Attributes:
        individual (bool): TODO: type description here.
        legal_entity (bool): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "individual":'individual',
        "legal_entity":'legalEntity'
    }

    def __init__(self,
                 individual=None,
                 legal_entity=None):
        """Constructor for the IdentityRestriction class"""

        # Initialize members of the class
        self.individual = individual
        self.legal_entity = legal_entity


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        individual = dictionary.get('individual')
        legal_entity = dictionary.get('legalEntity')

        # Return an object of this model
        return cls(individual,
                   legal_entity)





# -*- coding: utf-8 -*-

class PayerTypeEnum(object):

    """Implementation of the 'PayerType' enum.

    The type of Payer making the payment. This detrmines which identity
    details are used as the payer identity.

    Attributes:
        AUTHENTICATEDCALLER: Payout is being requested on behalf of the
            requesting merchant.
        MANAGEDMERCHANT: Payout is being requested on behalf of a managed
            merchant.
        USER: Payout is being requested on behalf of a user.

    """

    AUTHENTICATEDCALLER = 'authenticatedCaller'

    MANAGEDMERCHANT = 'managedMerchant'

    USER = 'user'




# -*- coding: utf-8 -*-


class AdditionalFieldWithValidator(object):

    """Implementation of the 'additionalFieldWithValidator' model.

    The 'Validation' attribute may contain a Regular Expression, which should
    be used to validate data before submission.

    Attributes:
        key (string): TODO: type description here.
        label (string): TODO: type description here.
        mandatory (bool): TODO: type description here.
        validation (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "key":'key',
        "label":'label',
        "mandatory":'mandatory',
        "validation":'validation'
    }

    def __init__(self,
                 key=None,
                 label=None,
                 mandatory=None,
                 validation=None):
        """Constructor for the AdditionalFieldWithValidator class"""

        # Initialize members of the class
        self.key = key
        self.label = label
        self.mandatory = mandatory
        self.validation = validation


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        key = dictionary.get('key')
        label = dictionary.get('label')
        mandatory = dictionary.get('mandatory')
        validation = dictionary.get('validation')

        # Return an object of this model
        return cls(key,
                   label,
                   mandatory,
                   validation)





# -*- coding: utf-8 -*-


class GetExpectedSettlementDateResponse(object):

    """Implementation of the 'Get Expected Settlement DateResponse' model.

    This is the response to the Validate Beneficiary Bank Account API.

    Attributes:
        is_bank_account_valid (bool): TODO: type description here.
        anticipated_payout_request_time (string): TODO: type description
            here.
        service_level (ServiceLevelEnum): Supported service levels for a
            payout request (standard or express).
        expected_settlement_date (string): Valid ISO 8601 date format
            YYYY-MM-DD.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "is_bank_account_valid":'isBankAccountValid',
        "anticipated_payout_request_time":'anticipatedPayoutRequestTime',
        "service_level":'serviceLevel',
        "expected_settlement_date":'expectedSettlementDate'
    }

    def __init__(self,
                 is_bank_account_valid=None,
                 anticipated_payout_request_time=None,
                 service_level=None,
                 expected_settlement_date=None):
        """Constructor for the GetExpectedSettlementDateResponse class"""

        # Initialize members of the class
        self.is_bank_account_valid = is_bank_account_valid
        self.anticipated_payout_request_time = anticipated_payout_request_time
        self.service_level = service_level
        self.expected_settlement_date = expected_settlement_date


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        is_bank_account_valid = dictionary.get('isBankAccountValid')
        anticipated_payout_request_time = dictionary.get('anticipatedPayoutRequestTime')
        service_level = dictionary.get('serviceLevel')
        expected_settlement_date = dictionary.get('expectedSettlementDate')

        # Return an object of this model
        return cls(is_bank_account_valid,
                   anticipated_payout_request_time,
                   service_level,
                   expected_settlement_date)





# -*- coding: utf-8 -*-

from ...configuration import Configuration

class CustomHeaderAuth:

    @staticmethod
    def apply(http_request):
        """ Add custom authentication to the request.

        Args:
            http_request (HttpRequest): The HttpRequest object to which 
                authentication will be added.

        """                
        http_request.add_header("Authorization", Configuration.authorization)



# -*- coding: utf-8 -*-

from .base_controller import BaseController
from ..api_helper import APIHelper
from ..configuration import Configuration
from ..http.auth.custom_header_auth import CustomHeaderAuth
from ..models.account_balance import AccountBalance
from ..exceptions.api_exception import APIException

class BalancesController(BaseController):

    """A Controller to access Endpoints in the earthport-rest-api-client API."""


    def get_balance(self,
                    managed_merchant_name=None,
                    currency=None):
        """Does a GET request to /balances.

        Retrieves the balance of a merchant account.

        Args:
            managed_merchant_name (string, optional): The name of managed
                merchant registered on EarthPort
            currency (string, optional): currency

        Returns:
            list of AccountBalance: Response from the API. Balance succesfully
                retrieved.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.get_base_uri()
        _query_builder += '/balances'
        _query_parameters = {
            'managedMerchantName': managed_merchant_name,
            'currency': currency
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 400:
            raise APIException('The requested operation could not be performed. Input Request is invalid or incorrect.', _context)
        elif _context.response.status_code == 401:
            raise APIException('Unauthorized - Invalid API Key and Token.', _context)
        elif _context.response.status_code == 500:
            raise APIException('An internal error has occurred in the Earthport payment platform.', _context)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, AccountBalance.from_dictionary)



# -*- coding: utf-8 -*-

class APIException(Exception):

    """Class that handles HTTP Exceptions when fetching API Endpoints.

    Attributes:
        response_code (int): The status code of the response.
        context (HttpContext): The HttpContext of the API call.

    """

    def __init__(self,
                 reason,
                 context):
        """Constructor for the APIException class

        Args:
            reason (string): The reason (or error message) for the Exception
                to be raised.            
            context (HttpContext): The HttpContext of the API call.

        """
        super(APIException, self).__init__(reason)
        self.context = context
        self.response_code = context.response.status_code



# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.purpose_of_payment_code

class PurposeOfPaymentFieldGroupsList(object):

    """Implementation of the 'purposeOfPaymentFieldGroupsList' model.

    This group contains all configuration information for Purpose of Payment
    options. The 'mandatory' attribute indicates whether provision of Purpose
    of Payment data is required for the Payout to be accepted.

    Attributes:
        mandatory (bool): TODO: type description here.
        purpose_of_payment_code (list of PurposeOfPaymentCode): TODO: type
            description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "mandatory":'mandatory',
        "purpose_of_payment_code":'purposeOfPaymentCode'
    }

    def __init__(self,
                 mandatory=None,
                 purpose_of_payment_code=None):
        """Constructor for the PurposeOfPaymentFieldGroupsList class"""

        # Initialize members of the class
        self.mandatory = mandatory
        self.purpose_of_payment_code = purpose_of_payment_code


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        mandatory = dictionary.get('mandatory')
        purpose_of_payment_code = None
        if dictionary.get('purposeOfPaymentCode') != None:
            purpose_of_payment_code = list()
            for structure in dictionary.get('purposeOfPaymentCode'):
                purpose_of_payment_code.append(earthport-rest-api-client.models.purpose_of_payment_code.PurposeOfPaymentCode.from_dictionary(structure))

        # Return an object of this model
        return cls(mandatory,
                   purpose_of_payment_code)





# -*- coding: utf-8 -*-

class HttpContext(object):

    """An HTTP Context that contains both the original HttpRequest
    object that intitiated the call and the HttpResponse object that
    is the result of the call.

    Attributes:
        request (HttpRequest): The original request object.
        response (HttpResponse): The returned response object after
            executing the request. Note that this may be None
            depending on if and when an error occurred.

    """

    def __init__(self,
                 request,
                 response):
        """Constructor for the HttpContext class

        Args:
            request (HttpRequest): The HTTP Request.
            response (HttpResponse): The HTTP Response.

        """
        self.request = request
        self.response = response



# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.beneficiary_identity_group
import earthport-rest-api-client.models.beneficiary_identity_field_group_choice

class BeneficiaryIdentityGroupsList(object):

    """Implementation of the 'BeneficiaryIdentityGroupsList' model.

    This type defines a list of identity data groups. Each group is normally
    represented as a section of fields on the UI.

    Attributes:
        group_label (string): TODO: type description here.
        beneficiary_identity_field_group (list of BeneficiaryIdentityGroup):
            TODO: type description here.
        beneficiary_identity_field_group_choice (list of
            BeneficiaryIdentityFieldGroupChoice): TODO: type description
            here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "group_label":'groupLabel',
        "beneficiary_identity_field_group":'beneficiaryIdentityFieldGroup',
        "beneficiary_identity_field_group_choice":'beneficiaryIdentityFieldGroupChoice'
    }

    def __init__(self,
                 group_label=None,
                 beneficiary_identity_field_group=None,
                 beneficiary_identity_field_group_choice=None):
        """Constructor for the BeneficiaryIdentityGroupsList class"""

        # Initialize members of the class
        self.group_label = group_label
        self.beneficiary_identity_field_group = beneficiary_identity_field_group
        self.beneficiary_identity_field_group_choice = beneficiary_identity_field_group_choice


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        group_label = dictionary.get('groupLabel')
        beneficiary_identity_field_group = None
        if dictionary.get('beneficiaryIdentityFieldGroup') != None:
            beneficiary_identity_field_group = list()
            for structure in dictionary.get('beneficiaryIdentityFieldGroup'):
                beneficiary_identity_field_group.append(earthport-rest-api-client.models.beneficiary_identity_group.BeneficiaryIdentityGroup.from_dictionary(structure))
        beneficiary_identity_field_group_choice = None
        if dictionary.get('beneficiaryIdentityFieldGroupChoice') != None:
            beneficiary_identity_field_group_choice = list()
            for structure in dictionary.get('beneficiaryIdentityFieldGroupChoice'):
                beneficiary_identity_field_group_choice.append(earthport-rest-api-client.models.beneficiary_identity_field_group_choice.BeneficiaryIdentityFieldGroupChoice.from_dictionary(structure))

        # Return an object of this model
        return cls(group_label,
                   beneficiary_identity_field_group,
                   beneficiary_identity_field_group_choice)





# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.beneficiary_bank_account_summary
import earthport-rest-api-client.models.user_id
import earthport-rest-api-client.models.pagination_result

class ListBankAccountsResponse(object):

    """Implementation of the 'List Bank AccountsResponse' model.

    This type gives a summary of the Beneficiary Bank Account.

    Attributes:
        beneficiary_bank_account_summary (list of
            BeneficiaryBankAccountSummary): TODO: type description here.
        user_id (UserID): This group consists of all possible user identifier
            types. The 'epUserID' field is a unique identifier for a merchant
            and is the equivalent of a Virtual Account Number (VAN). The
            'merchantUserID' is a merchant specified identifier for an
            individual or company that an account was set up for. The
            'epUserID', 'merchantUserID' or both 'epUserID' and
            'merchantUserID' can be supplied. A mapping will be performed to
            retrieve the merchant user ID from the supplied EP user ID and
            vice versa. If both the 'epUserID' and 'merchantUserID' are
            supplied, a check will be performed to ensure that the two are
            mapped. If the two provided fields are not mapped, then a
            validation error code will be returned. At least one of the fields
            must be populated.
        pagination_result (PaginationResult): This returns a paged set of
            results rather than the full result set.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "beneficiary_bank_account_summary":'beneficiaryBankAccountSummary',
        "user_id":'userID',
        "pagination_result":'paginationResult'
    }

    def __init__(self,
                 beneficiary_bank_account_summary=None,
                 user_id=None,
                 pagination_result=None):
        """Constructor for the ListBankAccountsResponse class"""

        # Initialize members of the class
        self.beneficiary_bank_account_summary = beneficiary_bank_account_summary
        self.user_id = user_id
        self.pagination_result = pagination_result


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        beneficiary_bank_account_summary = None
        if dictionary.get('beneficiaryBankAccountSummary') != None:
            beneficiary_bank_account_summary = list()
            for structure in dictionary.get('beneficiaryBankAccountSummary'):
                beneficiary_bank_account_summary.append(earthport-rest-api-client.models.beneficiary_bank_account_summary.BeneficiaryBankAccountSummary.from_dictionary(structure))
        user_id = earthport-rest-api-client.models.user_id.UserID.from_dictionary(dictionary.get('userID')) if dictionary.get('userID') else None
        pagination_result = earthport-rest-api-client.models.pagination_result.PaginationResult.from_dictionary(dictionary.get('paginationResult')) if dictionary.get('paginationResult') else None

        # Return an object of this model
        return cls(beneficiary_bank_account_summary,
                   user_id,
                   pagination_result)


